@@ -11,6 +11,12 @@ class CoDatascientistBackendResponse(BaseModel):
     code_to_run: CodeVersion | None = None
 
 
+class CoDatascientistBatchResponse(BaseModel):
+    workflow: Workflow
+    batch_to_run: list[CodeVersion] | None = None
+    batch_id: str
+
+
 async def test_connection() -> str:
     return await _call_co_datascientist_client("/test_connection", {})
 
@@ -43,6 +49,31 @@ async def finished_running_code(
     return CoDatascientistBackendResponse.model_validate(response)
 
 
+async def get_batch_to_run(workflow_id: str, batch_size: int | None = None) -> CoDatascientistBatchResponse:
+    payload: dict = {"workflow_id": workflow_id}
+    if batch_size is not None:
+        payload["batch_size"] = batch_size
+    response = await _call_co_datascientist_client("/get_batch_to_run", payload)
+    return CoDatascientistBatchResponse.model_validate(response)
+
+
+async def finished_running_batch(
+    workflow_id: str,
+    batch_id: str,
+    results: list[tuple[str, CodeResult]]
+) -> CoDatascientistBatchResponse:
+    payload = {
+        "workflow_id": workflow_id,
+        "batch_id": batch_id,
+        "results": [
+            {"code_version_id": code_version_id, "result": result.model_dump(mode="json")}
+            for code_version_id, result in results
+        ],
+    }
+    response = await _call_co_datascientist_client("/finished_running_batch", payload)
+    return CoDatascientistBatchResponse.model_validate(response)
+
+
 async def stop_workflow(workflow_id: str) -> None:
     await _call_co_datascientist_client("/stop_workflow", {"workflow_id": workflow_id})
 
