@@ -519,7 +519,7 @@ class _WorkflowRunner:
                 return
             os.unlink(local_tmp_meta)
             
-            print(f"✅ Checkpoint uploaded to: {VOLUME_URI}/{CHECKPOINTS_FOLDER}/{base_filename}.*")
+            # print(f"✅ Checkpoint uploaded to: {VOLUME_URI}/{CHECKPOINTS_FOLDER}/{base_filename}.*")
             
         except Exception as e:
             print(f"❌ Checkpoint upload error: {e}")
@@ -590,7 +590,7 @@ class _WorkflowRunner:
                 print(f"❌ Failed to upload current run metadata (uuid): {result.stderr}")
                 return
 
-            print(f"✅ Current run uploaded to: {VOLUME_URI}/{CURRENT_RUNS_FOLDER}/latest.* and run_{uid_safe}.*")
+            # print(f"✅ Current run uploaded to: {VOLUME_URI}/{CURRENT_RUNS_FOLDER}/latest.* and run_{uid_safe}.*")
         except Exception as e:
             print(f"❌ Current run upload error: {e}")
 
